# Dummy file :)
package Bundle::POE::All;
use vars qw( $VERSION );
$VERSION = '1.03';

# End of module
1;
__END__

=head1 NAME

Bundle::POE::All - Installs all the modules in the POE::* namespace

=head1 SYNOPSIS

	tar -zxf Bundle-POE-All*.tar.gz
	perl Makefile.PL
	make install

=head1 ABSTRACT

	This module installs all modules in the POE::* namespace

=head1 DESCRIPTION

This module will use CPANPLUS to retrieve all the modules under the POE::* namespace and install them.

This file, All.pm, is merely a placeholder and will be overwritten with a CONTENTS section when Makefile.PL
is run, thanks to the magic of CPANPLUS :)

=head1 AUTHOR

Apocalypse E<lt>apocal@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2008 by Apocalypse

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
